#!/bin/bash

# Function that, when given gsdlpath as parameter, will return the
# version of greenstone that is to run (2 or 3). If things are not,
# this program will exit here.
function get_version {
    # first parameter is value of gsdlpath
    if [ -f "${1}/gs3-setup.sh" ]; then
    return 3
    elif [ -f "${1}/setup.bash" ]; then
    return 2
    else
    echo "Error: can't determine which Greenstone version is being run."
    exit 1
    fi
}

# Function that is passed the following paramters (in order):
# - the gsdlpath (GS3 home, GS2 home or gs2build for GS3), 
# - the version of greenstone that's running, and 
# - the language GLI is set to
# and checks the installation. 
# If things are not right, this program will exit here.
function check_installation {
# Check that the Greenstone installation looks OK
    if [ "$3" = "es" ]; then
    echo "Revisando GSDL$2: $1"
    elif [ "$3" = "fr" ]; then
    echo "Vrification de GSDL$2: $1"
    elif [ "$3" = "ru" ]; then
    echo " GSDL$2: $1"
    else
    echo "Checking GSDL$2: $1"
    fi
    # even if we are only checking for gs2build (gsdl2path), we still 
    # need the file setup.bash to exist in the following condition:
    if [ ! -f "${1}/gs3-setup.sh" -a ! -f "${1}/setup.bash" ] ; then
    echo
    if [ "$3" = "es" ]; then
        echo "No se pudo encontrar la instalacin de Greenstone $2 o est incompleta."
        echo "Trate de reinstalar Greenstone $2 y a continuacin ejecute nuevamente"
        echo "este guin."
    elif [ "$3" = "fr" ]; then
        echo "L'installation de Greenstone $2 est introuvable ou incomplte."
        echo "Essayez de rinstaller Greenstone $2 et excutez ce script  nouveau."
    elif [ "$3" = "ru" ]; then
        echo " Greenstone $_version      ."
        echo "   Greenstone $2,      ."
    else
        echo "The Greenstone $2 installation could not be found, or is incomplete."
        echo "Try reinstalling Greenstone $2 then running this script again."
    fi
    exit 1
    fi
}

glilang=en

if [ "x$PROGNAME" = "x" ] ; then
  if [ "$glilang" = "es" ]; then
    PROGNAME="Biblioteca Digital Greenstone"
  elif [ "$glilang" = "fr" ]; then
    PROGNAME="Bibliothcaire Greenstone"
  elif [ "$glilang" = "ru" ]; then
    PROGNAME=" Greenstone"
  else
    PROGNAME="Greenstone Librarian Interface"
  fi
fi

if [ "x$PROGABBR" = "x" ] ; then
    PROGABBR="GLI"
fi

if [ "x$PROGNAME_EN" = "x" ] ; then
    PROGNAME_EN="Greenstone Librarian Interface"
fi

echo
if [ "$glilang" = "es" ]; then
    echo "Interfaz de la $PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2006, New Zealand Digital Library Project, University Of Waikato"
    echo "La Interfaz de la $PROGNAME NO INCLUYE ABSOLUTAMENTE NINGUNA GARANTA."
    echo "Para mayor informacin vea los trminos de la licencia en LICENSE.txt"
    echo "Este es un software abierto, por lo que lo invitamos a que lo distribuya de forma gratuita"
elif [ "$glilang" = "fr" ]; then
    echo "Interface du $PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2006, New Zealand Digital Library Project, University Of Waikato"
    echo "$PROGABBR est fourni sans AUCUNE GARANTIE; pour des dtails, voir LICENSE.txt"
    echo "Ceci est un logiciel libre, et vous tes invit  le redistribuer"
elif [ "$glilang" = "ru" ]; then
    echo " $PROGNAME ($PROGNAME_EN - $PROGABBR)"
    echo "Copyright (C) 2006, New Zealand Digital Library Project, University Of Waikato"
    echo "     ;  .   LICENSE.TXT"
    echo " -         "
else
    echo "$PROGNAME ($PROGABBR)"
    echo "Copyright (C) 2006, New Zealand Digital Library Project, University Of Waikato"
    echo "$PROGABBR comes with ABSOLUTELY NO WARRANTY; for details see LICENSE.txt"
    echo "This is free software, and you are welcome to redistribute it"
fi
echo

##  -------- Run the Greenstone Librarian Interface --------

# This script must be run from within the directory in which it lives
thisdir=`pwd`
if [ ! -f "${thisdir}/gli.sh" ]; then
    if [ "$glilang" = "es" ]; then
        echo "Este guin deber ejecutarse desde el directorio en el que reside."
    elif [ "$glilang" = "fr" ]; then
    echo "Ce script doit tre excut  partir du rpertoire dans lequel il se trouve."
    elif [ "$glilang" = "ru" ]; then
    echo "      ,    "
    else
    echo "This script must be run from the directory in which it resides."
    fi
    exit 1
fi


##  ---- Determine GSDLHOME ----
## gsdlpath can be either Greenstone 3 or Greenstone 2
gsdlpath=
# Some users may set the above line manually


# This variable is set automatically:
_version=
if [ "x$gsdlpath" != "x" ]; then
    get_version "$gsdlpath"
    _version=$?
# otherwise $gsdlpath is not yet set
else
    # Check the environment variable first
    # Check whether environment variables for both GS2 and GS3 are set
    # and if so, warn the user that we have defaulted to GS3
    if [ "x$GSDLHOME" != "x" -a "x$GSDL3SRCHOME" != "x" ]; then
        # _version not set, but both env vars set, so default to 3
    _version=3
    gsdlpath=$GSDL3SRCHOME
    echo "Both Greenstone 2 and Greenstone 3 environments are set." 
    echo "It is assumed you want to run Greenstone 3."
    echo "If you want to run Greenstone 2, please unset the"
    echo "environment variable GSDL3SRCHOME before running GLI."
    echo ""
    elif [ "x$GSDL3SRCHOME" != "x" ]; then
    echo "Only gsdl3srchome set"
    gsdlpath=$GSDL3SRCHOME
    _version=3
    echo "$gsdlpath"
    elif [ "x$GSDLHOME" != "x" ]; then
    gsdlpath=$GSDLHOME
    _version=2
    # If it is not set, assume that the GLI is installed as a subdirectory of Greenstone
    else
    gsdlpath=`(cd .. && pwd)`
    # Still need to find what version we are running:
    # GS3 main directory contains file gs3-setup.sh, GS2 only setup.bash
    get_version "$gsdlpath"
    _version=$?
    fi
fi

echo "Greenstone version found: $_version"

# Check that the main Greenstone installation for the version we're running looks OK
check_installation "$gsdlpath" "$_version" "$glilang"


# Need to source the correct setup file depending on whether we are running
# gs3 or gs2
# If we're running version GS2
if [ "$_version" -eq 2 ]; then
    # Setup Greenstone 2, unless it has already been done
    if [ "x$GSDLHOME" = "x" ]; then
    cd "$gsdlpath"
    . ./setup.bash
    cd "$thisdir"
    fi
# else, if we're running GS3
elif [ "$_version" -eq 3 ]; then
    # Setup Greenstone 3, unless it has already been done
    if [ "x$GSDL3HOME" = "x" -o "x$GSDL3SRCHOME" = "x" ]; then
    cd "$gsdlpath"
    . ./gs3-setup.sh
    cd "$thisdir"
    fi
    
    ## if Greenstone version 3 is running, we want to set gsdl2path
    ##  ---- Determine GSDLHOME ----
    ## may be already set, or manually entered here.
    gsdl2path=
    
    # Some users may set the above line manually
    if [ "x$gsdl2path" = "x" ]; then
        # Check the environment variable first
    if [ "x$GSDLHOME" != "x" ]; then
        echo "GSDLHOME environment variable is set to $GSDLHOME."
        echo "Will use this to find build scripts."
        gsdl2path=$GSDLHOME
        # If it is not set, assume that the gs2build subdirectory of Greenstone 3 exists
    else
        gsdl2path=$GSDL3SRCHOME/gs2build
    fi
    fi
    # Check that Greenstone 3's Greenstone 2 stuff looks OK (in gs2build)
    check_installation "$gsdl2path" "" "$glilang"
  
    # Setup Greenstone 3's gs2build, unless it has already been done
    if [ "x$GSDLHOME" = "x" ]; then
    cd "$gsdl2path"
    . ./setup.bash
    cd "$thisdir"
    fi

else 
    echo "Greenstone version unknown."    
    exit 1
fi

echo
if [ "x$GSDL3SRCHOME" != "x" ]; then
    echo "GSDL3SRCHOME is: $GSDL3SRCHOME"
fi
if [ "x$GSDL3HOME" != "x" ]; then
    echo "GSDL3HOME is: $GSDL3HOME"
fi
if [ "x$GSDLHOME" != "x" ]; then
    echo "GSDLHOME is: $GSDLHOME"
fi
echo

## ---- find perl ----
exit_status=0
./findperl.sh
exit_status=$?
if [ "$exit_status" -eq 1 ]; then
    exit 1;
fi

## ---- Check Java ----
# call the script with source, so that we have the variables it sets ($javapath)
exit_status=0
source ./findjava.sh
exit_status=$?
if [ "$exit_status" -eq 1 ]; then
    exit 1;
fi

## ---- Check that the GLI has been compiled ----
if [ ! -f "classes/org/greenstone/gatherer/GathererProg.class" ] && [ ! -f "GLI.jar" ]; then
    echo
    if [ "$glilang" = "es" ]; then
    echo "Usted necesita compilar la Interfaz de la Biblioteca Digital Greenstone"
    echo "(por medio de makegli.sh) antes de ejecutar este guin."
    elif [ "$glilang" = "fr" ]; then
    echo "Vous devez compiler le Greenstone Interface (en utilisant makegli.sh)"
    echo "avant d'excuter ce script."
    elif [ "$glilang" = "ru" ]; then
    echo "     Greenstone"
    echo "( makegli.sh)    "
    else
    echo "You need to compile the Greenstone Librarian Interface (using makegli.sh)"
    echo "before running this script."
    fi
    exit 1
fi

## ---- Explain how to bypass Imagemagick and Ghostscript bundled with Greenstone if needed ----
if [ -e "$GSDLHOME/bin/$GSDLOS/ghostscript" ] ; then
echo "GhostScript bundled with Greenstone will be used, if you wish to use the version installed on your system (if any) please go to $GSDLHOME/bin/$GSDLOS and rename the folder called ghostscript to something else."
fi
echo
echo
if [ -e "$GSDLHOME/bin/$GSDLOS/imagemagick" ] ; then
echo "ImageMagick bundled with Greenstone will be used, if you wish to use the version installed on your system (if any) please go to $GSDLHOME/bin/$GSDLOS and rename the folder called imagemagick to something else."
echo
echo
fi


## ---- Finally, run the GLI ----
if [ "$glilang" = "es" ]; then
    echo "Ejecutando la Interfaz de la $PROGNAME..."
elif [ "$glilang" = "fr" ]; then
    echo "Excution de $PROGNAME..."
elif [ "$glilang" = "ru" ]; then
    echo "  $PROGNAME..."
else
    echo "Running the $PROGNAME..."
fi

# basic_command is the cmd string common to both Greenstone 3 and Greenstone 2 execution
#basic_command="$javapath -Xmx128M -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar org.greenstone.gatherer.GathererProg"
stop_gli=0
while [ "$stop_gli" = "0" ] ; do 
    
    # Other arguments you can provide to GLI to work around memory limitations, or debug
    # -Xms<number>M    To set minimum memory (by default 32MB)
    # -Xmx<number>M    To set maximum memory (by default the nearest 2^n to the total remaining physical memory)
    # -verbose:gc      To set garbage collection messages
    # -Xincgc          For incremental garbage collection (significantly slows performance)
    # -Xprof           Function call profiling
    # -Xloggc:<file>   Write garbage collection log
    
    exit_status=0
    if [ "$_version" -eq 2 ]; then
# GS2 webLib
	if [ "$PROGABBR" = "FLI" -o ! -f "$GSDLHOME/gs2-server.sh" ]; then
	    "$javapath" -Xmx128M -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar org.greenstone.gatherer.GathererProg -gsdl "$GSDLHOME" -gsdlos $GSDLOS $*
	    exit_status=$?
# GS2 localLib
	else
	    "$javapath" -Xmx128M -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar org.greenstone.gatherer.GathererProg -gsdl "$GSDLHOME" -gsdlos $GSDLOS -local_library "$GSDLHOME/gs2-server.sh" $*
	    exit_status=$?
	fi
# GS3
    elif [ "$_version" -eq 3 ]; then    
        "$javapath" -Xmx128M -classpath classes/:GLI.jar:lib/apache.jar:lib/qfslib.jar org.greenstone.gatherer.GathererProg -gsdl "$GSDLHOME" -gsdlos $GSDLOS -gsdl3 "$GSDL3HOME" -gsdl3src "$GSDL3SRCHOME" $*
        exit_status=$?
    fi
    
    if [ "$exit_status" != "2" ] ; then
        stop_gli=1
    else
        echo
        if [ "$glilang" = "es" ]; then
            echo "Restarting/Ejecutando la Interfaz de la $PROGNAME..."
        elif [ "$glilang" = "fr" ]; then
            echo "Restarting/Excution de $PROGNAME..."
        elif [ "$glilang" = "ru" ]; then
            echo "Restarting/  $PROGNAME..."
        else
            echo "Restarting the $PROGNAME..."
        fi
    fi
done 

if [ "$glilang" = "es" ]; then
    echo "Hecho!"
elif [ "$glilang" = "fr" ]; then
    echo "Termin!"
elif [ "$glilang" = "ru" ]; then
    echo "!"
else
    echo "Done!"
fi
